============
scikit-sound
============

*scikit-sound* contains functions for working with sound 

Dependencies
------------
numpy, scipy

Homepage
--------
http://work.thaslwanter.at/sksound/html/

Author:  Thomas Haslwanter
Date:    23-03-2018
Ver:     0.2.0
Licence: BSD 2-Clause License (http://opensource.org/licenses/BSD-2-Clause)
        Copyright (c) 2018, Thomas Haslwanter
        All rights reserved.

Installation
------------
You can install scikit-sound with

    pip install scikit-sound

and upgrade to a new version with

    pip install scikit-sound -U

Sound Processing Utilities
==========================

- sounds.Sound ... class, with methods
    * generate_sound
    * get_info
    * play
    * read_sound
    * summary
    * write_wav
